@@ -1,7 +1,8 @@
 package Dist::Zilla::PluginBundle::Author::GSG;
 
 # ABSTRACT: Grant Street Group CPAN dists
-our $VERSION = '0.0.12'; # VERSION
+use version;
+our $VERSION = 'v0.0.13'; # VERSION
 
 use Moose;
 with qw(
@@ -23,34 +24,44 @@ sub configure {
         ) ]
     } );
 
+    # We need to reconfigure the MakeMaker Plugin to require
+    # a new enough version to support "version ranges".
+    # https://github.com/Perl-Toolchain-Gang/ExtUtils-MakeMaker/issues/215
+    my ($mm)
+        = grep { $_->[1] eq 'Dist::Zilla::Plugin::MakeMaker' }
+        @{ $self->plugins };
+
+    $mm->[2]->{eumm_version} = '7.1101';
+
     $self->add_plugins(
         'Author::GSG',
 
         'MetaJSON',
-        'OurPkgVersion',
+        [ 'OurPkgVersion' => {
+            semantic_version => 1,
+        } ],
         'Prereqs::FromCPANfile',
         'ReadmeAnyFromPod',
         $meta_provides,
 
-        [   'StaticInstall' => $self->config_slice(
-            {   static_install_mode    => 'mode',
-                static_install_dry_run => 'dry_run',
-            }
-        ) ],
+        [ 'StaticInstall' => $self->config_slice( {
+            static_install_mode    => 'mode',
+            static_install_dry_run => 'dry_run',
+        } ) ],
 
-        [   'PodWeaver' => {
-                replacer           => 'replace_with_comment',
-                post_code_replacer => 'replace_with_nothing',
-                config_plugin      => [ '@Default', 'Contributors' ]
-            }
-        ],
+        [ 'PodWeaver' => {
+            replacer           => 'replace_with_comment',
+            post_code_replacer => 'replace_with_nothing',
+            config_plugin      => [ '@Default', 'Contributors' ]
+        } ],
 
         [ 'ChangelogFromGit' => {
-            tag_regexp => '^v(\d+\.\d+\.\d+)$'
+            tag_regexp => '^(v\d+\.\d+\.\d+)$'
         } ],
 
         [ 'Git::NextVersion' => {
-            first_version => '0.0.1',
+            first_version  => 'v0.0.1',
+            version_regexp => '^(v\d+\.\d+\.\d+)$',
         } ],
 
         'Git::Commit',
@@ -124,7 +135,7 @@ Dist::Zilla::PluginBundle::Author::GSG - Grant Street Group CPAN dists
 
 =head1 VERSION
 
-version 0.0.12
+version v0.0.13
 
 =head1 SYNOPSIS
 
@@ -148,6 +159,10 @@ Some of which comes from L<Dist::Zilla::Plugin::Author::GSG>.
     -remove = UploadToCPAN
     -remove = GatherDir
 
+    # The MakeMaker Plugin gets an additional setting
+    # in order to support "version ranges".
+    eumm_version = 7.1101
+
     # The defaults for author and license come from
     #[Author::GSG]
 
@@ -167,10 +182,11 @@ Some of which comes from L<Dist::Zilla::Plugin::Author::GSG>.
     config_plugin = [ @Default, Contributors ]
 
     [ChangelogFromGit]
-    tag_regexp = ^v(\d+\.\d+\.\d+)$
+    tag_regexp = ^(v\d+\.\d+\.\d+)$
 
     [Git::NextVersion]
-    first_version = 0.0.1
+    first_version  = v0.0.1
+    version_regexp = ^(v\d+\.\d+\.\d+)$
 
     [Git::Commit]
     [Git::Tag]
